Learn R Programming

ffscrapr (version 1.4.7)

ffscrapr-package: ffscrapr: API Client for Fantasy Football League Platforms

Description

Helps access various Fantasy Football APIs by handling authentication and rate-limiting, forming appropriate calls, and returning tidy dataframes which can be easily connected to other data sources.

Arguments

See Also

Useful links: