powered by
Fetches a copy of roster data from nflfastr's data repository. The same input/output as nflfastr's fast_scraper_roster function.
nflfastr_rosters(seasons)
A numeric vector of seasons, earliest of which is 1999. TRUE returns all seasons, NULL returns latest season.
Data frame where each individual row represents a player in the roster of the given team and season
If you have any issues with the output of this data, please open an issue in the nflfastr repository.
https://nflreadr.nflverse.com
# NOT RUN { try( # try only shown here because sometimes CRAN checks are weird nflfastr_rosters(seasons = 2019:2020) ) # } # NOT RUN { # }
Run the code above in your browser using DataLab