Learn R Programming

ffscrapr (version 1.4.0)

espn_potentialpoints: ESPN Potential Points

Description

This function calculates the optimal starters for a given week, using some lineup heuristics.

Usage

espn_potentialpoints(conn, weeks = 1:17)

Arguments

conn

the list object created by ff_connect()

weeks

a numeric vector for determining which weeks to calculate

Value

a tibble with the best lineup for each team and whether they were started or not

Examples

Run this code
# NOT RUN {
conn <- espn_connect(season = 2020, league_id = 899513)
espn_potentialpoints(conn, weeks = 1:3)
# }

Run the code above in your browser using DataLab