powered by
This function calculates the optimal starters for a given week, using some lineup heuristics.
espn_potentialpoints(conn, weeks = 1:17)
the list object created by ff_connect()
ff_connect()
a numeric vector for determining which weeks to calculate
a tibble with the best lineup for each team and whether they were started or not
# NOT RUN { conn <- espn_connect(season = 2020, league_id = 899513) espn_potentialpoints(conn, weeks = 1:3) # }
Run the code above in your browser using DataLab