Learn R Programming

ffscrapr (version 1.4.0)

ff_starter_positions: Get Starting Lineup Settings

Description

This function returns a tidy dataframe with positional lineup rules.

Usage

ff_starter_positions(conn, ...)

# S3 method for espn_conn ff_starter_positions(conn, ...)

# S3 method for flea_conn ff_starter_positions(conn, ...)

# S3 method for mfl_conn ff_starter_positions(conn, ...)

# S3 method for sleeper_conn ff_starter_positions(conn, ...)

Arguments

conn

the list object created by ff_connect()

...

other arguments (currently unused)

Value

A tidy dataframe of positional lineup rules, one row per position with minimum and maximum starters as well as total starter calculations.

Methods (by class)

  • espn_conn: ESPN: returns min/max starters for each main player position

  • flea_conn: Fleaflicker: returns minimum and maximum starters for each player position.

  • mfl_conn: MFL: returns minimum and maximum starters for each player position.

  • sleeper_conn: Sleeper: returns minimum and maximum starters for each player position.

Examples

Run this code
# NOT RUN {
conn <- espn_connect(season = 2020, league_id = 1178049)
ff_starter_positions(conn)
# }
# NOT RUN {
# }
# NOT RUN {
conn <- fleaflicker_connect(season = 2020, league_id = 206154)
ff_starter_positions(conn)
# }
# NOT RUN {
# }
# NOT RUN {
dlfidp_conn <- mfl_connect(2020, league_id = 54040)
ff_starter_positions(conn = dlfidp_conn)
# }
# NOT RUN {
# }
# NOT RUN {
jml_conn <- sleeper_connect(league_id = "652718526494253056", season = 2021)
jml_starters <- ff_starter_positions(jml_conn)
# }
# NOT RUN {
# }

Run the code above in your browser using DataLab