Helps access various Fantasy Football APIs by handling authentication and rate-limiting, forming appropriate calls, and returning tidy dataframes which can be easily connected to other data sources.
Useful links:
Report bugs at https://github.com/ffverse/ffscrapr/issues