Learn R Programming

ffscrapr (version 1.4.0)

nflfastr_rosters: Import nflfastr roster data

Description

Fetches a copy of roster data from nflfastr's data repository. The same input/output as nflfastr's fast_scraper_roster function.

Usage

nflfastr_rosters(seasons)

Arguments

seasons

A numeric vector of seasons, earliest of which is 1999

Value

Data frame where each individual row represents a player in the roster of the given team and season

Details

If you have any issues with the output of this data, please open an issue in the nflfastr repository.

See Also

https://www.nflfastr.com/reference/fast_scraper_roster.html

Examples

Run this code
# NOT RUN {
nflfastr_rosters(seasons = 2019:2020)
# }
# NOT RUN {
# }

Run the code above in your browser using DataLab