powered by
Fetches a copy of roster data from nflfastr's data repository. The same input/output as nflfastr's fast_scraper_roster function.
nflfastr_rosters(seasons)
A numeric vector of seasons, earliest of which is 1999
Data frame where each individual row represents a player in the roster of the given team and season
If you have any issues with the output of this data, please open an issue in the nflfastr repository.
https://www.nflfastr.com/reference/fast_scraper_roster.html
# NOT RUN { nflfastr_rosters(seasons = 2019:2020) # } # NOT RUN { # }
Run the code above in your browser using DataLab