powered by
Fetches a copy of the latest week-level stats from nflfastr's data repository, via the nflreadr package.
nflfastr_weekly(seasons = TRUE, type = c("offense", "kicking"))
The seasons to return, TRUE returns all data available.
One of "offense" or "kicking"
Weekly stats for all passers, rushers and receivers in the nflverse play-by-play data from the 1999 season to the most recent season
The goal of this data is to replicate the NFL's official weekly stats, which can diverge a bit from what fantasy data feeds display.
If you have any issues with the output of this data, please open an issue in the nflfastr repository.
https://nflreadr.nflverse.com
# NOT RUN { try( # try only shown here because sometimes CRAN checks are weird nflfastr_weekly() ) # } # NOT RUN { # }
Run the code above in your browser using DataLab