powered by
Fetches a copy of the latest week-level stats from nflfastr's data repository. The same output as nflfastr's load_player_stats() function.
nflfastr_weekly(type = c("offense", "defense", "all"))
One of "offense", "defense", or "all" - currently, only "offense" is available.
Weekly stats for all passers, rushers and receivers in the nflfastR play-by-play data from the 1999 season to the most recent season
The goal of this data is to replicate the NFL's official weekly stats, which can diverge a bit from what fantasy data feeds display.
If you have any issues with the output of this data, please open an issue in the nflfastr repository.
https://www.nflfastr.com/reference/load_player_stats.html
# NOT RUN { nflfastr_weekly() # } # NOT RUN { # }
Run the code above in your browser using DataLab